@@ -6,8 +6,8 @@
   cat ("Working directory is", getwd(), "\n")
 #  options(digits = 2, papersize="letter")
 #  cat ("options( digits = ", getOption("digits"), ")\n")
-  if(!any(search()=="package:car"))
-    require(car)
+  #if(!any(search()=="package:car"))
+  #  require(car)
   if(!any(search()=="package:foreign"))
     require(foreign) 
   if(!any(search()=="package:MASS"))
